@@ -33,6 +33,23 @@ class PersonCard(PersonBlock):
     pass
 
 
+class ReviewCard(blocks.StructBlock):
+    score = blocks.IntegerBlock()
+    text = TextBlock()
+    media = blocks.StreamBlock(
+        [
+            ('svg', SvgWithSizeBlock()),
+            ('image', ImageWithSizeBlock()),
+        ],
+        max_num=1,
+        required=False
+    )
+
+    class Meta:
+        template = '%s/common/review_card.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Review Card"
+
+
 class CardsEntry(EntryBlock):
     amp_scripts = ['carousel']
     theme_reverse = ThemeChoiceBlock(required=False)
@@ -41,7 +58,8 @@ class CardsEntry(EntryBlock):
     cards = blocks.StreamBlock(
         [
             ('custom', CustomCard()),
-            ('person', PersonCard())
+            ('person', PersonCard()),
+            ('review', ReviewCard()),
         ],
         min_num=1
     )
