@@ -51,6 +51,12 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
     youtube = models.URLField(blank=True, help_text='Youtube page URL')
 
     brand_name = models.CharField(default='', blank=True, max_length=100)
+    brand_short_name = models.CharField(default='', blank=True, max_length=100)
+    brand_description = models.TextField(default='', blank=True)
+
+    primary_color_uks = models.CharField(default='', blank=True, max_length=20)
+    primary_bg_color = models.CharField(default='', blank=True, max_length=20)
+
     logo_header_primary = StreamField([
         ('image', ImageChooserBlock(label="Image - ratio 200x55")),
         ('svg', DocumentChooserBlock(label="Svg - ratio 200x55")),
@@ -156,6 +162,8 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
         help_text="Ajoute le choix des langages dans le footer"
     )
 
+
+
     general_panels = [
         FieldPanel('language'),
         FieldPanel('ga_code'),
@@ -182,6 +190,10 @@ class AWebspaceSettings(BaseSetting, ClusterableModel):
 
     brand_tab_panels = [
         FieldPanel('brand_name'),
+        FieldPanel('brand_short_name'),
+        FieldPanel('brand_description'),
+        FieldPanel('primary_color_uks'),
+        FieldPanel('primary_bg_color'),
         StreamFieldPanel('logo_header_primary'),
         StreamFieldPanel('logo_header_secondary'),
         ImageChooserPanel('favicon'),
